import java.io.File;
import java.io.FileNotFoundException;
import java.util.Map;
import java.util.Scanner;

/**
 * The Weather data class provides a way of reading a file in the format
 * of the weather_data.csv file, and computing some statistics from that data
 */
public class WeatherData {
	Scanner dataScanner;
	String filepath;
    
	/**
	 * This constructs a WeatherData object with a default file location
	 */
	public WeatherData(){
		this("weather_data.csv");
	}
	
	/**
	 * This constructs a WeatherData object to read the data from a file
	 * in the given path
	 * @param path The location of the weather data comma separated file
	 */
	public WeatherData(String path){
        filepath = path;
	}
	
	/**
	 * Opens the Scanner object used to read the file
	 */
	public void open(){
		// Initialize data scanner
		try {
			dataScanner = new Scanner(new File(filepath));
		} catch (FileNotFoundException e) {
			System.out.println("The file "+filepath+" was not found.");
			e.printStackTrace();
		}
	}

	/**
	 * Closes the Scanner object used to read the file
	 */
	public void close(){
		dataScanner.close();
	}

	/**
	 *  This method returns the average monthly temperature, computed
	 *  from the daily temperatures between startYear and endYear
	 * @param startYear
	 * @param endYear
	 * @return An array with the monthly average temperature
	 */
	public double[] getMonthlyTemperature(int startYear, int endYear){
		double[] data = new double[12];
		int[] number_of_days = new int[12];

		this.open();
		// skip first line
		dataScanner.nextLine();
		while(dataScanner.hasNext()){
			String[] line = dataScanner.nextLine().split(",");
			int year = Integer.parseInt(line[0]);
			if( year >= startYear && year <= endYear){
				int month = Integer.parseInt(line[1])-1;
				try{
					data[month] += Double.parseDouble(line[5]);
					number_of_days[month]++;
				} catch(NumberFormatException e){
					// ignore this value
					continue;
				}
			}
		}

		for (int month=0; month < 12; month++) {
			data[month] /= number_of_days[month];
		}
        this.close();
		return data;
	}

	/**
	 *  This method returns the average monthly temperature, computed
	 *  from the daily temperatures between startYear and endYear
	 * @param startYear
	 * @param endYear
	 * @return An array with the monthly average temperature
	 */
	public double[] getMonthlyTemperature(int year){   	    	
		return getMonthlyTemperature(year, year);
	}

	public int[] getMonthlyDaysAboveTemperature(double temperature,int startYear, int endYear){
		int[] data = new int[12];
		
		this.open();
		// skip first line
		dataScanner.nextLine();
		while(dataScanner.hasNext()){
			String[] line = dataScanner.nextLine().split(",");
			int year = Integer.parseInt(line[0]);
			if( year >= startYear && year <= endYear){
				int month = Integer.parseInt(line[1])-1;
				try{
					if (Double.parseDouble(line[3]) >= temperature){
						data[month]++;
					}
				} catch(NumberFormatException e){
					// ignore this value
					continue;
				}
			}
		}

		for (int month=0; month < 12; month++) {
			data[month] /= (endYear-startYear+1);
		}
		this.close();
		return data;
	}

	public int[] getMonthlyDaysAboveTemperature(double temperature, int year){   	    	
		return getMonthlyDaysAboveTemperature(temperature,year, year);
	}

}
